@@ -2,32 +2,31 @@ import os
 import json
 import click
 from dotenv import load_dotenv
-from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileId, FileContentsQuery
+from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery
 import subprocess
 
 load_dotenv()
 
-OPERATOR_ID= AccountId.fromString(os.environ["OPERATOR_ID"])
-OPERATOR_KEY= PrivateKey.fromString(os.environ["OPERATOR_KEY"])
+OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
+OPERATOR_KEY = PrivateKey.fromString(os.getenv("OPERATOR_KEY"))
 
 class Network3Medusa():
     def __init__(self, command):
         self.command = command
 
     def network3_medusa(self):
-        parsed_json = self.py2output()
+        self.py2output()
+        parsed_json=self.output.stdout
         self.add_file_to_hedera(parsed_json)
         
     def py2output(self):
-        output = subprocess.run(["python", "call_clid.py", self.command])
-        return(output)
+        self.output = subprocess.run(["python", "call_clid.py", self.command], capture_output=True)
 
     def add_file_to_hedera(self, parsed_json):
         client = Client.forTestnet()
         client.setOperator(OPERATOR_ID, OPERATOR_KEY)
-        fileContents = parsed_json
         tran = FileCreateTransaction()
-        resp = tran.setKeys(OPERATOR_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(client)
+        resp = tran.setContents(parsed_json).setMaxTransactionFee(Hbar(2)).execute(client)
         print("nodeId: ",  resp.nodeId.toString())
         receipt = resp.getReceipt(client)
         fileId = receipt.fileId
